Cookbook recipes
================

Cookbook are short tutorials: 1 page, 5 minutes to read.


.. toctree::
   :maxdepth: 2

   calibrate
   integration_with_the_gui
   integration_with_scripts
   integration_with_python


For more in depth explanation, see the tutorials section.